summaryrefslogtreecommitdiff
path: root/plugins/pythonconsole
diff options
context:
space:
mode:
authorPerberos <[email protected]>2011-11-07 19:52:18 -0300
committerPerberos <[email protected]>2011-11-07 19:52:18 -0300
commit5ded9cba8563f336939400303d6a841d5089b107 (patch)
treec5676588cff26ba37e12369fe4de24b54e9f6682 /plugins/pythonconsole
parentf00b3a11a199f9f85a4d46a600f9d14179b37dbf (diff)
downloadpluma-5ded9cba8563f336939400303d6a841d5089b107.tar.bz2
pluma-5ded9cba8563f336939400303d6a841d5089b107.tar.xz
renaming from gedit to pluma
Diffstat (limited to 'plugins/pythonconsole')
-rwxr-xr-xplugins/pythonconsole/Makefile.am8
-rwxr-xr-xplugins/pythonconsole/pythonconsole.pluma-plugin.desktop.in (renamed from plugins/pythonconsole/pythonconsole.gedit-plugin.desktop.in)4
-rwxr-xr-xplugins/pythonconsole/pythonconsole/Makefile.am4
-rwxr-xr-xplugins/pythonconsole/pythonconsole/__init__.py14
-rwxr-xr-xplugins/pythonconsole/pythonconsole/config.py4
-rwxr-xr-xplugins/pythonconsole/pythonconsole/console.py2
6 files changed, 18 insertions, 18 deletions
diff --git a/plugins/pythonconsole/Makefile.am b/plugins/pythonconsole/Makefile.am
index c27227f3..53361183 100755
--- a/plugins/pythonconsole/Makefile.am
+++ b/plugins/pythonconsole/Makefile.am
@@ -1,11 +1,11 @@
# Python Console Plugin
SUBDIRS = pythonconsole
-plugindir = $(GEDIT_PLUGINS_LIBS_DIR)
+plugindir = $(PLUMA_PLUGINS_LIBS_DIR)
-plugin_in_files = pythonconsole.gedit-plugin.desktop.in
-%.gedit-plugin: %.gedit-plugin.desktop.in $(INTLTOOL_MERGE) $(wildcard $(top_srcdir)/po/*po) ; $(INTLTOOL_MERGE) $(top_srcdir)/po $< $@ -d -u -c $(top_builddir)/po/.intltool-merge-cache
+plugin_in_files = pythonconsole.pluma-plugin.desktop.in
+%.pluma-plugin: %.pluma-plugin.desktop.in $(INTLTOOL_MERGE) $(wildcard $(top_srcdir)/po/*po) ; $(INTLTOOL_MERGE) $(top_srcdir)/po $< $@ -d -u -c $(top_builddir)/po/.intltool-merge-cache
-plugin_DATA = $(plugin_in_files:.gedit-plugin.desktop.in=.gedit-plugin)
+plugin_DATA = $(plugin_in_files:.pluma-plugin.desktop.in=.pluma-plugin)
EXTRA_DIST = $(plugin_in_files)
diff --git a/plugins/pythonconsole/pythonconsole.gedit-plugin.desktop.in b/plugins/pythonconsole/pythonconsole.pluma-plugin.desktop.in
index 8cc65648..ca941412 100755
--- a/plugins/pythonconsole/pythonconsole.gedit-plugin.desktop.in
+++ b/plugins/pythonconsole/pythonconsole.pluma-plugin.desktop.in
@@ -1,4 +1,4 @@
-[Gedit Plugin]
+[Pluma Plugin]
Loader=python
Module=pythonconsole
IAge=2
@@ -7,4 +7,4 @@ _Description=Interactive Python console standing in the bottom panel
Icon=mate-mime-text-x-python
Authors=Steve Frécinaux <[email protected]>
Copyright=Copyright © 2006 Steve Frécinaux
-Website=http://www.gedit.org
+Website=http://www.pluma.org
diff --git a/plugins/pythonconsole/pythonconsole/Makefile.am b/plugins/pythonconsole/pythonconsole/Makefile.am
index 7aa91fe9..05327ed6 100755
--- a/plugins/pythonconsole/pythonconsole/Makefile.am
+++ b/plugins/pythonconsole/pythonconsole/Makefile.am
@@ -1,12 +1,12 @@
# Python console plugin
-plugindir = $(GEDIT_PLUGINS_LIBS_DIR)/pythonconsole
+plugindir = $(PLUMA_PLUGINS_LIBS_DIR)/pythonconsole
plugin_PYTHON = \
__init__.py \
console.py \
config.py
-uidir = $(GEDIT_PLUGINS_DATA_DIR)/pythonconsole/ui
+uidir = $(PLUMA_PLUGINS_DATA_DIR)/pythonconsole/ui
ui_DATA = config.ui
EXTRA_DIST = $(ui_DATA)
diff --git a/plugins/pythonconsole/pythonconsole/console.py b/plugins/pythonconsole/pythonconsole/console.py
index e9d7a331..5e818727 100755
--- a/plugins/pythonconsole/pythonconsole/console.py
+++ b/plugins/pythonconsole/pythonconsole/console.py
@@ -21,7 +21,7 @@
# Parts from "Interactive Python-GTK Console" (stolen from epiphany's console.py)
# Copyright (C), 1998 James Henstridge <[email protected]>
# Copyright (C), 2005 Adam Hooper <[email protected]>
-# Bits from gedit Python Console Plugin
+# Bits from pluma Python Console Plugin
# Copyrignt (C), 2005 Raphaël Slinckx
import string
diff --git a/plugins/pythonconsole/pythonconsole/__init__.py b/plugins/pythonconsole/pythonconsole/__init__.py
index 60f70e9f..699225f0 100755
--- a/plugins/pythonconsole/pythonconsole/__init__.py
+++ b/plugins/pythonconsole/pythonconsole/__init__.py
@@ -21,11 +21,11 @@
# Parts from "Interactive Python-GTK Console" (stolen from epiphany's console.py)
# Copyright (C), 1998 James Henstridge <[email protected]>
# Copyright (C), 2005 Adam Hooper <[email protected]>
# Bits from gedit Python Console Plugin
# Copyrignt (C), 2005 Raphaël Slinckx
import gtk
-import gedit
+import pluma
from console import PythonConsole
from config import PythonConsoleConfigDialog
@@ -33,14 +33,14 @@ from config import PythonConsoleConfig
PYTHON_ICON = 'mate-mime-text-x-python'
-class PythonConsolePlugin(gedit.Plugin):
+class PythonConsolePlugin(pluma.Plugin):
def __init__(self):
- gedit.Plugin.__init__(self)
+ pluma.Plugin.__init__(self)
self.dlg = None
def activate(self, window):
console = PythonConsole(namespace = {'__builtins__' : __builtins__,
- 'gedit' : gedit,
+ 'pluma' : pluma,
'window' : window})
console.eval('print "You can access the main window through ' \
'\'window\' :\\n%s" % window', False)
@@ -63,14 +63,14 @@ def create_configure_dialog(self):
self.dlg = PythonConsoleConfigDialog(self.get_data_dir())
dialog = self.dlg.dialog()
- window = gedit.app_get_default().get_active_window()
+ window = pluma.app_get_default().get_active_window()
if window:
dialog.set_transient_for(window)
return dialog
# Here we dynamically insert create_configure_dialog based on if configuration
# is enabled. This has to be done like this because gedit checks if a plugin
# is configurable solely on the fact that it has this member defined or not
if PythonConsoleConfig.enabled():
PythonConsolePlugin.create_configure_dialog = create_configure_dialog
@@ -21,11 +21,11 @@
# Copyright (C), 1998 James Henstridge <[email protected]>
# Copyright (C), 2005 Adam Hooper <[email protected]>
-# Bits from gedit Python Console Plugin
+# Bits from pluma Python Console Plugin
# Copyrignt (C), 2005 Raphaël Slinckx
import gtk
@@ -63,14 +63,14 @@ def create_configure_dialog(self):
return dialog
# Here we dynamically insert create_configure_dialog based on if configuration
-# is enabled. This has to be done like this because gedit checks if a plugin
+# is enabled. This has to be done like this because pluma checks if a plugin
# is configurable solely on the fact that it has this member defined or not
if PythonConsoleConfig.enabled():
diff --git a/plugins/pythonconsole/pythonconsole/config.py b/plugins/pythonconsole/pythonconsole/config.py
index fed4699b..ac0e599c 100755
--- a/plugins/pythonconsole/pythonconsole/config.py
+++ b/plugins/pythonconsole/pythonconsole/config.py
@@ -21,7 +21,7 @@
# Parts from "Interactive Python-GTK Console" (stolen from epiphany's console.py)
# Copyright (C), 1998 James Henstridge <[email protected]>
# Copyright (C), 2005 Adam Hooper <[email protected]>
# Bits from gedit Python Console Plugin
# Copyrignt (C), 2005 Raphaël Slinckx
import os
@@ -29,7 +29,7 @@ import gtk
__all__ = ('PythonConsoleConfig', 'PythonConsoleConfigDialog')
-MATECONF_KEY_BASE = '/apps/gedit-2/plugins/pythonconsole'
+MATECONF_KEY_BASE = '/apps/pluma-2/plugins/pythonconsole'
MATECONF_KEY_COMMAND_COLOR = MATECONF_KEY_BASE + '/command-color'
MATECONF_KEY_ERROR_COLOR = MATECONF_KEY_BASE + '/error-color'
@@ -21,7 +21,7 @@
# Copyright (C), 1998 James Henstridge <[email protected]>
# Copyright (C), 2005 Adam Hooper <[email protected]>
-# Bits from gedit Python Console Plugin
+# Bits from pluma Python Console Plugin
# Copyrignt (C), 2005 Raphaël Slinckx
import os